==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/MonitorUI/src/com/clustercontrol/monitor/view/action/StatusFilterAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.bean.Property;
import com.clustercontrol.monitor.dialog.StatusFilterDialog;
import com.clustercontrol.monitor.view.StatusView;

/**
 * ơˤ븡Ԥ󥯥饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class StatusFilterAction implements IViewActionDelegate {

    //	 ----- instance ե ----- //

    private IViewPart viewPart; // ӥ塼

    // ----- instance ᥽å ----- //

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        StatusView view = (StatusView) this.viewPart
                .getAdapter(StatusView.class);

        if (action.isChecked()) {
            // 
            StatusFilterDialog dialog = new StatusFilterDialog(this.viewPart
                    .getSite().getShell());

            // ˤƸ򤵤줿硢̤ӥ塼ɽ
            if (dialog.open() == IDialogConstants.OK_ID) {
                Property condition = dialog.getInputData();

                view.setCondition(condition);
                view.update();
            } else {
                action.setChecked(false);
            }
        } else {
            // 說ꥢ
            view.setCondition(null);

            // ץĥ꡼Υƥ(ץѥʸκɽΤ)
            TreeViewer tree = view.getScopeTreeComposite().getTreeViewer();

            // ץĥ꡼Υƥब򤵤Ƥ
            if (((StructuredSelection) tree.getSelection()).getFirstElement() != null) {
                tree.setSelection(tree.getSelection()); // ӥ塼ιԤ
            }
            // ץĥ꡼Υƥब򤵤Ƥʤ
            else {
                view.update();
            }
        }
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/MonitorUI/src/com/clustercontrol/monitor/view/action/StatusFilterAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.bean.Property;
import com.clustercontrol.monitor.dialog.StatusFilterDialog;
import com.clustercontrol.monitor.view.StatusView;

/**
 * 監視[ステータスのフィルタ処理]ダイアログによるステータスの取得処理を行うアクションクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class StatusFilterAction implements IViewActionDelegate {

	/** ビュー */
    private IViewPart viewPart;


    /**
     * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * 監視[ステータスのフィルタ処理]ダイアログで指定された条件に一致するステータス情報を取得し、
     * ビューを更新します。
     * <p>
	 * <ol>
	 * <li>監視[ステータスのフィルタ処理]ダイアログを表示します。</li>
	 * <li>ダイアログで指定された検索条件を取得します。</li>
	 * <li>監視[ステータス]ビューの検索条件に設定します。</li>
	 * <li>監視[ステータス]ビューを更新します。</li>
	 * </ol>
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     * @see com.clustercontrol.monitor.dialog.StatusFilterDialog
     * @see com.clustercontrol.monitor.view.StatusView#setCondition(Property)
     * @see com.clustercontrol.monitor.view.StatusView#update() 
     */
    public void run(IAction action) {
        StatusView view = (StatusView) this.viewPart
                .getAdapter(StatusView.class);

        if (action.isChecked()) {
            // ダイアログを生成
            StatusFilterDialog dialog = new StatusFilterDialog(this.viewPart
                    .getSite().getShell());

            // ダイアログにて検索が選択された場合、検索結果をビューに表示
            if (dialog.open() == IDialogConstants.OK_ID) {
                Property condition = dialog.getInputData();

                view.setCondition(condition);
                view.update();
            } else {
                action.setChecked(false);
            }
        } else {
            // 検索条件クリア
            view.setCondition(null);

            // スコープツリーのアイテムを再選択(スコープパス文字列の再表示のため)
            TreeViewer tree = view.getScopeTreeComposite().getTreeViewer();

            // スコープツリーのアイテムが選択されていた場合
            if (((StructuredSelection) tree.getSelection()).getFirstElement() != null) {
                tree.setSelection(tree.getSelection()); // ビューの更新も行われる
            }
            // スコープツリーのアイテムが選択されていない場合
            else {
                view.update();
            }
        }
    }

    /**
     * 選択を変更した際に呼ばれます。
     * 
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}
